@@ -144,6 +144,7 @@ Usage::
         ListImagesInRecycleBinPaginator,
         ListSnapshotsInRecycleBinPaginator,
         NatGatewayAvailableWaiter,
+        NatGatewayDeletedWaiter,
         NetworkInterfaceAvailableWaiter,
         PasswordDataAvailableWaiter,
         SearchLocalGatewayRoutesPaginator,
@@ -187,6 +188,7 @@ Usage::
     internet_gateway_exists_waiter: InternetGatewayExistsWaiter = client.get_waiter("internet_gateway_exists")
     key_pair_exists_waiter: KeyPairExistsWaiter = client.get_waiter("key_pair_exists")
     nat_gateway_available_waiter: NatGatewayAvailableWaiter = client.get_waiter("nat_gateway_available")
+    nat_gateway_deleted_waiter: NatGatewayDeletedWaiter = client.get_waiter("nat_gateway_deleted")
     network_interface_available_waiter: NetworkInterfaceAvailableWaiter = client.get_waiter("network_interface_available")
     password_data_available_waiter: PasswordDataAvailableWaiter = client.get_waiter("password_data_available")
     security_group_exists_waiter: SecurityGroupExistsWaiter = client.get_waiter("security_group_exists")
@@ -468,6 +470,7 @@ from .waiter import (
     InternetGatewayExistsWaiter,
     KeyPairExistsWaiter,
     NatGatewayAvailableWaiter,
+    NatGatewayDeletedWaiter,
     NetworkInterfaceAvailableWaiter,
     PasswordDataAvailableWaiter,
     SecurityGroupExistsWaiter,
@@ -631,6 +634,7 @@ __all__ = (
     "ListImagesInRecycleBinPaginator",
     "ListSnapshotsInRecycleBinPaginator",
     "NatGatewayAvailableWaiter",
+    "NatGatewayDeletedWaiter",
     "NetworkInterfaceAvailableWaiter",
     "PasswordDataAvailableWaiter",
     "SearchLocalGatewayRoutesPaginator",
