@@ -993,6 +993,14 @@ InstanceTypeType = Literal[
     "c6i.large",
     "c6i.metal",
     "c6i.xlarge",
+    "c7g.12xlarge",
+    "c7g.16xlarge",
+    "c7g.2xlarge",
+    "c7g.4xlarge",
+    "c7g.8xlarge",
+    "c7g.large",
+    "c7g.medium",
+    "c7g.xlarge",
     "cc1.4xlarge",
     "cc2.8xlarge",
     "cg1.4xlarge",
@@ -1079,6 +1087,7 @@ InstanceTypeType = Literal[
     "i4i.4xlarge",
     "i4i.8xlarge",
     "i4i.large",
+    "i4i.metal",
     "i4i.xlarge",
     "im4gn.16xlarge",
     "im4gn.2xlarge",
@@ -1381,12 +1390,14 @@ InstanceTypeType = Literal[
     "x2idn.16xlarge",
     "x2idn.24xlarge",
     "x2idn.32xlarge",
+    "x2idn.metal",
     "x2iedn.16xlarge",
     "x2iedn.24xlarge",
     "x2iedn.2xlarge",
     "x2iedn.32xlarge",
     "x2iedn.4xlarge",
     "x2iedn.8xlarge",
+    "x2iedn.metal",
     "x2iedn.xlarge",
     "x2iezn.12xlarge",
     "x2iezn.2xlarge",
@@ -1903,6 +1914,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -1939,6 +1951,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -2012,6 +2025,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -2068,6 +2082,7 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshiftserverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
